.. labscript documentation master file, created by
   sphinx-quickstart on Mon Dec 08 14:26:41 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

labscript
=========
**labscript**, a component of the labscript suite, is an API used to define the experiment logic of a buffered experiment shot. This documentation will outline the general device hierarchy used when defining a connection table, and the **labscript** classes used to command input and output. For device specific documentation, and documentation for adding support for new devices, please refer to the :doc:`labscript-devices <labscript-devices:index>` documentation.


.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: DOCUMENTATION

   introduction
   connection_table
   api/index

.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: FURTHER DOCUMENTATION

   components

.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: LINKS

   Home Page <http://labscriptsuite.org>
   Source Code <https://github.com/labscript-suite/labscript>
   PyPI <https://pypi.org/project/labscript/>
   Anaconda Cloud <https://anaconda.org/labscript-suite/labscript>
   BitBucket Archive <http://bitbucket-archive.labscriptsuite.org/#!/labscript_suite/labscript>

.. todolist:: 


